require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Finman
    module BusinessCase
      # Value object containing attributes of a Business Case entity.
      class BusinessCaseAttributes < UU::OS::REST::DTO

        # URI of the Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of created Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for created Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Security level of the Business Case.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the Business Case.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the Business Case.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the Business Case.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the Business Case.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the Business Case.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the Business Case.
        # @param [UU::OS::Artifact::ArtifactWidthType]
        # @return [UU::OS::Artifact::ArtifactWidthType]
        attr_accessor :width

        # UESURI of the entity type of the artifact
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        # URI of the icon of the Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # URI of company of created Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :business_case_company_uri

        # Type of the business case. Returns value from  {UU::Finman::BusinessCase::BusinessCaseType} enumeration.
        # Can be null, if the type of the business case cannot be recognized.
        # @param [UU::Finman::BusinessCase::BusinessCaseType]
        # @return [UU::Finman::BusinessCase::BusinessCaseType]
        attr_accessor :business_case_type

        # Code of business case currency. Must be one from territory allowed reporting currencies.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # URI of related business case of interterritorial business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :related_business_case_uri

        # URI of counterparty business case of interterritorial business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # URI of access role for payments of interterritorial business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :access_role_for_payments_uri

        # URI of default account of the business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :default_account_uri

        # Default account number of the business case.
        # @param [String]
        # @return [String]
        attr_accessor :default_account_number

        # URI of incoming invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_invoice_clerk_uri

        # URI of outgoing invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_invoice_clerk_uri

        #URI of accountant's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :accountant_uri

        # URI of teller's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :teller_uri

        # URI of role of the teller's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :tellers_manager_uri

        # URI of incoming payment checker's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_payment_checker_uri

        # URI of role of the incoming payment checker's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_payment_checkers_manager_uri

        # URI of outgoing payment checker's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_payment_checker_uri

        # URI of role of the outgoing payment checker's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_payment_checkers_manager_uri

        # URI of default financial category of credit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_debit_financial_category_uri

        # URI of default financial category of credit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_credit_financial_category_uri

        # URI of default financial category of debit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_debit_financial_category_uri

        # URI of default financial category of credit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_debit_financial_category_uri

        # URI of default financial category of supplier's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_supplier_default_financial_category_uri

        # URI of default financial category of client's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_client_default_financial_category_uri
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          attributes[:iconUri] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          attributes[:entityTypeUri] = val
        end

        def business_case_company_uri
          attributes[:businessCaseCompanyUri]
        end

        def business_case_company_uri=(val)
          if val
            attributes[:businessCaseCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:businessCaseCompanyUri] = nil
          end
        end

        def business_case_type
          attributes[:businessCaseType]
        end

        def business_case_type=(val)
          attributes[:businessCaseType] = val
        end

        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end

        def related_business_case_uri
          attributes[:relatedBusinessCaseUri]
        end

        def related_business_case_uri=(val)
          if val
            attributes[:relatedBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedBusinessCaseUri] = nil
          end
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          if val
            attributes[:counterpartyBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:counterpartyBusinessCaseUri] = nil
          end
        end

        def access_role_for_payments_uri
          attributes[:accessRoleForPaymentsUri]
        end

        def access_role_for_payments_uri=(val)
          if val
            attributes[:accessRoleForPaymentsUri] = UU::OS::UESURI.new(val)
          else
            attributes[:accessRoleForPaymentsUri] = nil
          end
        end

        def default_account_uri
          attributes[:defaultAccountUri]
        end

        def default_account_uri=(val)
          if val
            attributes[:defaultAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultAccountUri] = nil
          end
        end

        def default_account_number
          attributes[:defaultAccountNumber]
        end

        def default_account_number=(val)
          attributes[:defaultAccountNumber] = val
        end

        def incoming_invoice_clerk_uri
          attributes[:incomingInvoiceClerkUri]
        end

        def incoming_invoice_clerk_uri=(val)
          if val
            attributes[:incomingInvoiceClerkUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingInvoiceClerkUri] = nil
          end
        end

        def outgoing_invoice_clerk_uri
          attributes[:outgoingInvoiceClerkUri]
        end

        def outgoing_invoice_clerk_uri=(val)
          if val
            attributes[:outgoingInvoiceClerkUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingInvoiceClerkUri] = nil
          end
        end

        def accountant_uri
          attributes[:accountantUri]
        end

        def accountant_uri=(val)
          if val
            attributes[:accountantUri] = UU::OS::UESURI.new(val)
          else
            attributes[:accountantUri] = nil
          end
        end

        def teller_uri
          attributes[:tellerUri]
        end

        def teller_uri=(val)
          if val
            attributes[:tellerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:tellerUri] = nil
          end
        end

        def tellers_manager_uri
          attributes[:tellersManagerUri]
        end

        def tellers_manager_uri=(val)
          if val
            attributes[:tellersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:tellersManagerUri] = nil
          end
        end

        def incoming_payment_checker_uri
          attributes[:incomingPaymentCheckerUri]
        end

        def incoming_payment_checker_uri=(val)
          if val
            attributes[:incomingPaymentCheckerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingPaymentCheckerUri] = nil
          end
        end

        def incoming_payment_checkers_manager_uri
          attributes[:incomingPaymentCheckersManagerUri]
        end

        def incoming_payment_checkers_manager_uri=(val)
          if val
            attributes[:incomingPaymentCheckersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingPaymentCheckersManagerUri] = nil
          end
        end

        def outgoing_payment_checker_uri
          attributes[:outgoingPaymentCheckerUri]
        end

        def outgoing_payment_checker_uri=(val)
          if val
            attributes[:outgoingPaymentCheckerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingPaymentCheckerUri] = nil
          end
        end

        def outgoing_payment_checkers_manager_uri
          attributes[:outgoingPaymentCheckersManagerUri]
        end

        def outgoing_payment_checkers_manager_uri=(val)
          if val
            attributes[:outgoingPaymentCheckersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingPaymentCheckersManagerUri] = nil
          end
        end

        def payment_default_credit_financial_category_uri
          attributes[:paymentDefaultCreditFinancialCategoryUri]
        end

        def payment_default_credit_financial_category_uri=(val)
          if val
            attributes[:paymentDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def payment_default_debit_financial_category_uri
          attributes[:paymentDefaultDebitFinancialCategoryUri]
        end

        def payment_default_debit_financial_category_uri=(val)
          if val
            attributes[:paymentDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def transfer_default_credit_financial_category_uri
          attributes[:transferDefaultCreditFinancialCategoryUri]
        end

        def transfer_default_credit_financial_category_uri=(val)
          if val
            attributes[:transferDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def transfer_default_debit_financial_category_uri
          attributes[:transferDefaultDebitFinancialCategoryUri]
        end

        def transfer_default_debit_financial_category_uri=(val)
          if val
            attributes[:transferDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def expost_payment_default_credit_financial_category_uri
          attributes[:expostPaymentDefaultCreditFinancialCategoryUri]
        end

        def expost_payment_default_credit_financial_category_uri=(val)
          if val
            attributes[:expostPaymentDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostPaymentDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def expost_payment_default_debit_financial_category_uri
          attributes[:expostPaymentDefaultDebitFinancialCategoryUri]
        end

        def expost_payment_default_debit_financial_category_uri=(val)
          if val
            attributes[:expostPaymentDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostPaymentDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def credit_note_supplier_default_financial_category_uri
          attributes[:creditNoteSupplierDefaultFinancialCategoryUri]
        end

        def credit_note_supplier_default_financial_category_uri=(val)
          if val
            attributes[:creditNoteSupplierDefaultFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteSupplierDefaultFinancialCategoryUri] = nil
          end
        end

        def credit_note_client_default_financial_category_uri
          attributes[:creditNoteClientDefaultFinancialCategoryUri]
        end

        def credit_note_client_default_financial_category_uri=(val)
          if val
            attributes[:creditNoteClientDefaultFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteClientDefaultFinancialCategoryUri] = nil
          end
        end
      end
    end
  end
end
